# coding: utf-8

"""
SpeechTextAnalyticsApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class SpeechTextAnalyticsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def delete_speechandtextanalytics_program(self, program_id, **kwargs):
        """
        Delete a Speech & Text Analytics program by id
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_speechandtextanalytics_program(program_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str program_id: The id of the program (required)
        :param bool force_delete: Indicates whether the program is forced to be deleted or not. Required when the program to delete is the default program.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['program_id', 'force_delete']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_speechandtextanalytics_program" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'program_id' is set
        if ('program_id' not in params) or (params['program_id'] is None):
            raise ValueError("Missing the required parameter `program_id` when calling `delete_speechandtextanalytics_program`")


        resource_path = '/api/v2/speechandtextanalytics/programs/{programId}'.replace('{format}', 'json')
        path_params = {}
        if 'program_id' in params:
            path_params['programId'] = params['program_id']

        query_params = {}
        if 'force_delete' in params:
            query_params['forceDelete'] = params['force_delete']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_speechandtextanalytics_topic(self, topic_id, **kwargs):
        """
        Delete a Speech & Text Analytics topic by id
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_speechandtextanalytics_topic(topic_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str topic_id: The id of the topic (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['topic_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_speechandtextanalytics_topic" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'topic_id' is set
        if ('topic_id' not in params) or (params['topic_id'] is None):
            raise ValueError("Missing the required parameter `topic_id` when calling `delete_speechandtextanalytics_topic`")


        resource_path = '/api/v2/speechandtextanalytics/topics/{topicId}'.replace('{format}', 'json')
        path_params = {}
        if 'topic_id' in params:
            path_params['topicId'] = params['topic_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_speechandtextanalytics_conversation(self, conversation_id, **kwargs):
        """
        Get Speech and Text Analytics for a specific conversation
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_speechandtextanalytics_conversation(conversation_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: Conversation Id (required)
        :return: ConversationMetrics
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_speechandtextanalytics_conversation" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `get_speechandtextanalytics_conversation`")


        resource_path = '/api/v2/speechandtextanalytics/conversations/{conversationId}'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ConversationMetrics',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_speechandtextanalytics_conversation_communication_transcripturl(self, conversation_id, communication_id, **kwargs):
        """
        Get the pre-signed S3 URL for the transcript of a specific communication of a conversation
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_speechandtextanalytics_conversation_communication_transcripturl(conversation_id, communication_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: Conversation ID (required)
        :param str communication_id: Communication ID (required)
        :return: TranscriptUrl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'communication_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_speechandtextanalytics_conversation_communication_transcripturl" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `get_speechandtextanalytics_conversation_communication_transcripturl`")
        # verify the required parameter 'communication_id' is set
        if ('communication_id' not in params) or (params['communication_id'] is None):
            raise ValueError("Missing the required parameter `communication_id` when calling `get_speechandtextanalytics_conversation_communication_transcripturl`")


        resource_path = '/api/v2/speechandtextanalytics/conversations/{conversationId}/communications/{communicationId}/transcripturl'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']
        if 'communication_id' in params:
            path_params['communicationId'] = params['communication_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='TranscriptUrl',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_speechandtextanalytics_dialects(self, **kwargs):
        """
        Get list of supported Speech & Text Analytics dialects
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_speechandtextanalytics_dialects(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: list[object]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_speechandtextanalytics_dialects" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/speechandtextanalytics/dialects'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='list[object]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_speechandtextanalytics_program(self, program_id, **kwargs):
        """
        Get a Speech & Text Analytics program by id
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_speechandtextanalytics_program(program_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str program_id: The id of the program (required)
        :return: Program
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['program_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_speechandtextanalytics_program" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'program_id' is set
        if ('program_id' not in params) or (params['program_id'] is None):
            raise ValueError("Missing the required parameter `program_id` when calling `get_speechandtextanalytics_program`")


        resource_path = '/api/v2/speechandtextanalytics/programs/{programId}'.replace('{format}', 'json')
        path_params = {}
        if 'program_id' in params:
            path_params['programId'] = params['program_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Program',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_speechandtextanalytics_programs(self, **kwargs):
        """
        Get the list of Speech & Text Analytics programs
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_speechandtextanalytics_programs(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str next_page: The key for listing the next page
        :param int page_size: The page size for the listing
        :return: ProgramsEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['next_page', 'page_size']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_speechandtextanalytics_programs" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/speechandtextanalytics/programs'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'next_page' in params:
            query_params['nextPage'] = params['next_page']
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ProgramsEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_speechandtextanalytics_programs_general_job(self, job_id, **kwargs):
        """
        Get a Speech & Text Analytics general program job by id
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_speechandtextanalytics_programs_general_job(job_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str job_id: The id of the publish programs job (required)
        :return: GeneralProgramJob
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_speechandtextanalytics_programs_general_job" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'job_id' is set
        if ('job_id' not in params) or (params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `get_speechandtextanalytics_programs_general_job`")


        resource_path = '/api/v2/speechandtextanalytics/programs/general/jobs/{jobId}'.replace('{format}', 'json')
        path_params = {}
        if 'job_id' in params:
            path_params['jobId'] = params['job_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='GeneralProgramJob',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_speechandtextanalytics_programs_publishjob(self, job_id, **kwargs):
        """
        Get a Speech & Text Analytics publish programs job by id
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_speechandtextanalytics_programs_publishjob(job_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str job_id: The id of the publish programs job (required)
        :return: ProgramJob
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_speechandtextanalytics_programs_publishjob" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'job_id' is set
        if ('job_id' not in params) or (params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `get_speechandtextanalytics_programs_publishjob`")


        resource_path = '/api/v2/speechandtextanalytics/programs/publishjobs/{jobId}'.replace('{format}', 'json')
        path_params = {}
        if 'job_id' in params:
            path_params['jobId'] = params['job_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ProgramJob',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_speechandtextanalytics_programs_unpublished(self, **kwargs):
        """
        Get the list of Speech & Text Analytics unpublished programs
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_speechandtextanalytics_programs_unpublished(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str next_page: The key for listing the next page
        :param int page_size: The page size for the listing
        :return: UnpublishedProgramsEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['next_page', 'page_size']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_speechandtextanalytics_programs_unpublished" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/speechandtextanalytics/programs/unpublished'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'next_page' in params:
            query_params['nextPage'] = params['next_page']
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UnpublishedProgramsEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_speechandtextanalytics_settings(self, **kwargs):
        """
        Get Speech And Text Analytics Settings
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_speechandtextanalytics_settings(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: SpeechTextAnalyticsSettingsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_speechandtextanalytics_settings" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/speechandtextanalytics/settings'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='SpeechTextAnalyticsSettingsResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_speechandtextanalytics_topic(self, topic_id, **kwargs):
        """
        Get a Speech & Text Analytics topic by id
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_speechandtextanalytics_topic(topic_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str topic_id: The id of the topic (required)
        :return: Topic
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['topic_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_speechandtextanalytics_topic" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'topic_id' is set
        if ('topic_id' not in params) or (params['topic_id'] is None):
            raise ValueError("Missing the required parameter `topic_id` when calling `get_speechandtextanalytics_topic`")


        resource_path = '/api/v2/speechandtextanalytics/topics/{topicId}'.replace('{format}', 'json')
        path_params = {}
        if 'topic_id' in params:
            path_params['topicId'] = params['topic_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Topic',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_speechandtextanalytics_topics(self, **kwargs):
        """
        Get the list of Speech & Text Analytics topics
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_speechandtextanalytics_topics(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str next_page: The key for listing the next page
        :param int page_size: The page size for the listing
        :return: TopicsEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['next_page', 'page_size']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_speechandtextanalytics_topics" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/speechandtextanalytics/topics'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'next_page' in params:
            query_params['nextPage'] = params['next_page']
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='TopicsEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_speechandtextanalytics_topics_general(self, **kwargs):
        """
        Get the Speech & Text Analytics general topics for a given dialect
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_speechandtextanalytics_topics_general(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str dialect: The dialect of the general topics, dialect format is {language}-{country} where language follows ISO 639-1 standard and country follows ISO 3166-1 alpha 2 standard
        :return: GeneralTopicsEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dialect']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_speechandtextanalytics_topics_general" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/speechandtextanalytics/topics/general'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'dialect' in params:
            query_params['dialect'] = params['dialect']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='GeneralTopicsEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_speechandtextanalytics_topics_publishjob(self, job_id, **kwargs):
        """
        Get a Speech & Text Analytics publish topics job by id
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_speechandtextanalytics_topics_publishjob(job_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str job_id: The id of the publish topics job (required)
        :return: TopicJob
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_speechandtextanalytics_topics_publishjob" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'job_id' is set
        if ('job_id' not in params) or (params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `get_speechandtextanalytics_topics_publishjob`")


        resource_path = '/api/v2/speechandtextanalytics/topics/publishjobs/{jobId}'.replace('{format}', 'json')
        path_params = {}
        if 'job_id' in params:
            path_params['jobId'] = params['job_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='TopicJob',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def patch_speechandtextanalytics_settings(self, body, **kwargs):
        """
        Patch Speech And Text Analytics Settings
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.patch_speechandtextanalytics_settings(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param SpeechTextAnalyticsSettingsRequest body: Speech And Text Analytics Settings (required)
        :return: SpeechTextAnalyticsSettingsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_speechandtextanalytics_settings" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `patch_speechandtextanalytics_settings`")


        resource_path = '/api/v2/speechandtextanalytics/settings'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'PATCH',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='SpeechTextAnalyticsSettingsResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_speechandtextanalytics_programs(self, body, **kwargs):
        """
        Create new Speech & Text Analytics program
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_speechandtextanalytics_programs(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ProgramRequest body: The program to create (required)
        :return: Program
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_speechandtextanalytics_programs" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_speechandtextanalytics_programs`")


        resource_path = '/api/v2/speechandtextanalytics/programs'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Program',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_speechandtextanalytics_programs_general_jobs(self, body, **kwargs):
        """
        Create new Speech & Text Analytics general program job
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_speechandtextanalytics_programs_general_jobs(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param GeneralProgramJobRequest body: The general programs job to create (required)
        :return: GeneralProgramJob
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_speechandtextanalytics_programs_general_jobs" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_speechandtextanalytics_programs_general_jobs`")


        resource_path = '/api/v2/speechandtextanalytics/programs/general/jobs'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='GeneralProgramJob',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_speechandtextanalytics_programs_publishjobs(self, body, **kwargs):
        """
        Create new Speech & Text Analytics publish programs job
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_speechandtextanalytics_programs_publishjobs(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ProgramJobRequest body: The publish programs job to create (required)
        :return: ProgramJob
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_speechandtextanalytics_programs_publishjobs" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_speechandtextanalytics_programs_publishjobs`")


        resource_path = '/api/v2/speechandtextanalytics/programs/publishjobs'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ProgramJob',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_speechandtextanalytics_topics(self, body, **kwargs):
        """
        Create new Speech & Text Analytics topic
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_speechandtextanalytics_topics(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TopicRequest body: The topic to create (required)
        :return: Topic
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_speechandtextanalytics_topics" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_speechandtextanalytics_topics`")


        resource_path = '/api/v2/speechandtextanalytics/topics'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Topic',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_speechandtextanalytics_topics_publishjobs(self, body, **kwargs):
        """
        Create new Speech & Text Analytics publish topics job
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_speechandtextanalytics_topics_publishjobs(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TopicJobRequest body: The publish topics job to create (required)
        :return: TopicJob
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_speechandtextanalytics_topics_publishjobs" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_speechandtextanalytics_topics_publishjobs`")


        resource_path = '/api/v2/speechandtextanalytics/topics/publishjobs'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='TopicJob',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_speechandtextanalytics_transcripts_search(self, body, **kwargs):
        """
        Search resources.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_speechandtextanalytics_transcripts_search(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TranscriptSearchRequest body: Search request options (required)
        :return: JsonSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_speechandtextanalytics_transcripts_search" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_speechandtextanalytics_transcripts_search`")


        resource_path = '/api/v2/speechandtextanalytics/transcripts/search'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='JsonSearchResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_speechandtextanalytics_program(self, program_id, body, **kwargs):
        """
        Update existing Speech & Text Analytics program
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_speechandtextanalytics_program(program_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str program_id: The id of the program (required)
        :param ProgramRequest body: The program to update (required)
        :return: Program
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['program_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_speechandtextanalytics_program" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'program_id' is set
        if ('program_id' not in params) or (params['program_id'] is None):
            raise ValueError("Missing the required parameter `program_id` when calling `put_speechandtextanalytics_program`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_speechandtextanalytics_program`")


        resource_path = '/api/v2/speechandtextanalytics/programs/{programId}'.replace('{format}', 'json')
        path_params = {}
        if 'program_id' in params:
            path_params['programId'] = params['program_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Program',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_speechandtextanalytics_topic(self, topic_id, body, **kwargs):
        """
        Update existing Speech & Text Analytics topic
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_speechandtextanalytics_topic(topic_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str topic_id: The id of the topic (required)
        :param TopicRequest body: The topic to update (required)
        :return: Topic
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['topic_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_speechandtextanalytics_topic" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'topic_id' is set
        if ('topic_id' not in params) or (params['topic_id'] is None):
            raise ValueError("Missing the required parameter `topic_id` when calling `put_speechandtextanalytics_topic`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_speechandtextanalytics_topic`")


        resource_path = '/api/v2/speechandtextanalytics/topics/{topicId}'.replace('{format}', 'json')
        path_params = {}
        if 'topic_id' in params:
            path_params['topicId'] = params['topic_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Topic',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Trunk(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Trunk - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'trunk_type': 'str',
            'edge': 'DomainEntityRef',
            'trunk_base': 'DomainEntityRef',
            'trunk_metabase': 'DomainEntityRef',
            'edge_group': 'DomainEntityRef',
            'in_service': 'bool',
            'enabled': 'bool',
            'logical_interface': 'DomainEntityRef',
            'connected_status': 'TrunkConnectedStatus',
            'options_status': 'list[TrunkMetricsOptions]',
            'registers_status': 'list[TrunkMetricsRegisters]',
            'ip_status': 'TrunkMetricsNetworkTypeIp',
            'options_enabled_status': 'str',
            'registers_enabled_status': 'str',
            'family': 'int',
            'proxy_address_list': 'list[str]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'trunk_type': 'trunkType',
            'edge': 'edge',
            'trunk_base': 'trunkBase',
            'trunk_metabase': 'trunkMetabase',
            'edge_group': 'edgeGroup',
            'in_service': 'inService',
            'enabled': 'enabled',
            'logical_interface': 'logicalInterface',
            'connected_status': 'connectedStatus',
            'options_status': 'optionsStatus',
            'registers_status': 'registersStatus',
            'ip_status': 'ipStatus',
            'options_enabled_status': 'optionsEnabledStatus',
            'registers_enabled_status': 'registersEnabledStatus',
            'family': 'family',
            'proxy_address_list': 'proxyAddressList',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._trunk_type = None
        self._edge = None
        self._trunk_base = None
        self._trunk_metabase = None
        self._edge_group = None
        self._in_service = None
        self._enabled = None
        self._logical_interface = None
        self._connected_status = None
        self._options_status = None
        self._registers_status = None
        self._ip_status = None
        self._options_enabled_status = None
        self._registers_enabled_status = None
        self._family = None
        self._proxy_address_list = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Trunk.
        The globally unique identifier for the object.

        :return: The id of this Trunk.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Trunk.
        The globally unique identifier for the object.

        :param id: The id of this Trunk.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Trunk.
        The name of the entity.

        :return: The name of this Trunk.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Trunk.
        The name of the entity.

        :param name: The name of this Trunk.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Trunk.
        The resource's description.

        :return: The description of this Trunk.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Trunk.
        The resource's description.

        :param description: The description of this Trunk.
        :type: str
        """
        
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this Trunk.
        The current version of the resource.

        :return: The version of this Trunk.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Trunk.
        The current version of the resource.

        :param version: The version of this Trunk.
        :type: int
        """
        
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this Trunk.
        The date the resource was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this Trunk.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this Trunk.
        The date the resource was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this Trunk.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this Trunk.
        The date of the last modification to the resource. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this Trunk.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this Trunk.
        The date of the last modification to the resource. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this Trunk.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this Trunk.
        The ID of the user that last modified the resource.

        :return: The modified_by of this Trunk.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this Trunk.
        The ID of the user that last modified the resource.

        :param modified_by: The modified_by of this Trunk.
        :type: str
        """
        
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this Trunk.
        The ID of the user that created the resource.

        :return: The created_by of this Trunk.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this Trunk.
        The ID of the user that created the resource.

        :param created_by: The created_by of this Trunk.
        :type: str
        """
        
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this Trunk.
        Indicates if the resource is active, inactive, or deleted.

        :return: The state of this Trunk.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Trunk.
        Indicates if the resource is active, inactive, or deleted.

        :param state: The state of this Trunk.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this Trunk.
        The application that last modified the resource.

        :return: The modified_by_app of this Trunk.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this Trunk.
        The application that last modified the resource.

        :param modified_by_app: The modified_by_app of this Trunk.
        :type: str
        """
        
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this Trunk.
        The application that created the resource.

        :return: The created_by_app of this Trunk.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this Trunk.
        The application that created the resource.

        :param created_by_app: The created_by_app of this Trunk.
        :type: str
        """
        
        self._created_by_app = created_by_app

    @property
    def trunk_type(self):
        """
        Gets the trunk_type of this Trunk.
        The type of this trunk.

        :return: The trunk_type of this Trunk.
        :rtype: str
        """
        return self._trunk_type

    @trunk_type.setter
    def trunk_type(self, trunk_type):
        """
        Sets the trunk_type of this Trunk.
        The type of this trunk.

        :param trunk_type: The trunk_type of this Trunk.
        :type: str
        """
        allowed_values = ["EXTERNAL", "PHONE", "EDGE"]
        if trunk_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for trunk_type -> " + trunk_type)
            self._trunk_type = "outdated_sdk_version"
        else:
            self._trunk_type = trunk_type

    @property
    def edge(self):
        """
        Gets the edge of this Trunk.
        The Edge using this trunk.

        :return: The edge of this Trunk.
        :rtype: DomainEntityRef
        """
        return self._edge

    @edge.setter
    def edge(self, edge):
        """
        Sets the edge of this Trunk.
        The Edge using this trunk.

        :param edge: The edge of this Trunk.
        :type: DomainEntityRef
        """
        
        self._edge = edge

    @property
    def trunk_base(self):
        """
        Gets the trunk_base of this Trunk.
        The trunk base configuration used on this trunk.

        :return: The trunk_base of this Trunk.
        :rtype: DomainEntityRef
        """
        return self._trunk_base

    @trunk_base.setter
    def trunk_base(self, trunk_base):
        """
        Sets the trunk_base of this Trunk.
        The trunk base configuration used on this trunk.

        :param trunk_base: The trunk_base of this Trunk.
        :type: DomainEntityRef
        """
        
        self._trunk_base = trunk_base

    @property
    def trunk_metabase(self):
        """
        Gets the trunk_metabase of this Trunk.
        The metabase used to create this trunk.

        :return: The trunk_metabase of this Trunk.
        :rtype: DomainEntityRef
        """
        return self._trunk_metabase

    @trunk_metabase.setter
    def trunk_metabase(self, trunk_metabase):
        """
        Sets the trunk_metabase of this Trunk.
        The metabase used to create this trunk.

        :param trunk_metabase: The trunk_metabase of this Trunk.
        :type: DomainEntityRef
        """
        
        self._trunk_metabase = trunk_metabase

    @property
    def edge_group(self):
        """
        Gets the edge_group of this Trunk.
        The edge group associated with this trunk.

        :return: The edge_group of this Trunk.
        :rtype: DomainEntityRef
        """
        return self._edge_group

    @edge_group.setter
    def edge_group(self, edge_group):
        """
        Sets the edge_group of this Trunk.
        The edge group associated with this trunk.

        :param edge_group: The edge_group of this Trunk.
        :type: DomainEntityRef
        """
        
        self._edge_group = edge_group

    @property
    def in_service(self):
        """
        Gets the in_service of this Trunk.
        True if this trunk is in-service.  This comes from the trunk_enabled property of the referenced trunk base.

        :return: The in_service of this Trunk.
        :rtype: bool
        """
        return self._in_service

    @in_service.setter
    def in_service(self, in_service):
        """
        Sets the in_service of this Trunk.
        True if this trunk is in-service.  This comes from the trunk_enabled property of the referenced trunk base.

        :param in_service: The in_service of this Trunk.
        :type: bool
        """
        
        self._in_service = in_service

    @property
    def enabled(self):
        """
        Gets the enabled of this Trunk.
        True if the Edge used by this trunk is in-service

        :return: The enabled of this Trunk.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this Trunk.
        True if the Edge used by this trunk is in-service

        :param enabled: The enabled of this Trunk.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def logical_interface(self):
        """
        Gets the logical_interface of this Trunk.
        The Logical Interface on the Edge to which the trunk is assigned.

        :return: The logical_interface of this Trunk.
        :rtype: DomainEntityRef
        """
        return self._logical_interface

    @logical_interface.setter
    def logical_interface(self, logical_interface):
        """
        Sets the logical_interface of this Trunk.
        The Logical Interface on the Edge to which the trunk is assigned.

        :param logical_interface: The logical_interface of this Trunk.
        :type: DomainEntityRef
        """
        
        self._logical_interface = logical_interface

    @property
    def connected_status(self):
        """
        Gets the connected_status of this Trunk.
        The connected status of the trunk

        :return: The connected_status of this Trunk.
        :rtype: TrunkConnectedStatus
        """
        return self._connected_status

    @connected_status.setter
    def connected_status(self, connected_status):
        """
        Sets the connected_status of this Trunk.
        The connected status of the trunk

        :param connected_status: The connected_status of this Trunk.
        :type: TrunkConnectedStatus
        """
        
        self._connected_status = connected_status

    @property
    def options_status(self):
        """
        Gets the options_status of this Trunk.
        The trunk optionsStatus

        :return: The options_status of this Trunk.
        :rtype: list[TrunkMetricsOptions]
        """
        return self._options_status

    @options_status.setter
    def options_status(self, options_status):
        """
        Sets the options_status of this Trunk.
        The trunk optionsStatus

        :param options_status: The options_status of this Trunk.
        :type: list[TrunkMetricsOptions]
        """
        
        self._options_status = options_status

    @property
    def registers_status(self):
        """
        Gets the registers_status of this Trunk.
        The trunk registersStatus

        :return: The registers_status of this Trunk.
        :rtype: list[TrunkMetricsRegisters]
        """
        return self._registers_status

    @registers_status.setter
    def registers_status(self, registers_status):
        """
        Sets the registers_status of this Trunk.
        The trunk registersStatus

        :param registers_status: The registers_status of this Trunk.
        :type: list[TrunkMetricsRegisters]
        """
        
        self._registers_status = registers_status

    @property
    def ip_status(self):
        """
        Gets the ip_status of this Trunk.
        The trunk ipStatus

        :return: The ip_status of this Trunk.
        :rtype: TrunkMetricsNetworkTypeIp
        """
        return self._ip_status

    @ip_status.setter
    def ip_status(self, ip_status):
        """
        Sets the ip_status of this Trunk.
        The trunk ipStatus

        :param ip_status: The ip_status of this Trunk.
        :type: TrunkMetricsNetworkTypeIp
        """
        
        self._ip_status = ip_status

    @property
    def options_enabled_status(self):
        """
        Gets the options_enabled_status of this Trunk.
        Returns Enabled when the trunk base supports the availability interval and it has a value greater than 0.

        :return: The options_enabled_status of this Trunk.
        :rtype: str
        """
        return self._options_enabled_status

    @options_enabled_status.setter
    def options_enabled_status(self, options_enabled_status):
        """
        Sets the options_enabled_status of this Trunk.
        Returns Enabled when the trunk base supports the availability interval and it has a value greater than 0.

        :param options_enabled_status: The options_enabled_status of this Trunk.
        :type: str
        """
        allowed_values = ["ENABLED", "DISABLED", "NOT_SUPPORTED"]
        if options_enabled_status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for options_enabled_status -> " + options_enabled_status)
            self._options_enabled_status = "outdated_sdk_version"
        else:
            self._options_enabled_status = options_enabled_status

    @property
    def registers_enabled_status(self):
        """
        Gets the registers_enabled_status of this Trunk.
        Returns Enabled when the trunk base supports the registration interval and it has a value greater than 0.

        :return: The registers_enabled_status of this Trunk.
        :rtype: str
        """
        return self._registers_enabled_status

    @registers_enabled_status.setter
    def registers_enabled_status(self, registers_enabled_status):
        """
        Sets the registers_enabled_status of this Trunk.
        Returns Enabled when the trunk base supports the registration interval and it has a value greater than 0.

        :param registers_enabled_status: The registers_enabled_status of this Trunk.
        :type: str
        """
        allowed_values = ["ENABLED", "DISABLED", "NOT_SUPPORTED"]
        if registers_enabled_status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for registers_enabled_status -> " + registers_enabled_status)
            self._registers_enabled_status = "outdated_sdk_version"
        else:
            self._registers_enabled_status = registers_enabled_status

    @property
    def family(self):
        """
        Gets the family of this Trunk.
        The IP Network Family of the trunk

        :return: The family of this Trunk.
        :rtype: int
        """
        return self._family

    @family.setter
    def family(self, family):
        """
        Sets the family of this Trunk.
        The IP Network Family of the trunk

        :param family: The family of this Trunk.
        :type: int
        """
        
        self._family = family

    @property
    def proxy_address_list(self):
        """
        Gets the proxy_address_list of this Trunk.
        The list of proxy addresses (ports if provided) for the trunk

        :return: The proxy_address_list of this Trunk.
        :rtype: list[str]
        """
        return self._proxy_address_list

    @proxy_address_list.setter
    def proxy_address_list(self, proxy_address_list):
        """
        Sets the proxy_address_list of this Trunk.
        The list of proxy addresses (ports if provided) for the trunk

        :param proxy_address_list: The proxy_address_list of this Trunk.
        :type: list[str]
        """
        
        self._proxy_address_list = proxy_address_list

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Trunk.
        The URI for this object

        :return: The self_uri of this Trunk.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Trunk.
        The URI for this object

        :param self_uri: The self_uri of this Trunk.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmIntradayDataUpdateTopicIntradayDataGroup(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmIntradayDataUpdateTopicIntradayDataGroup - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'media_type': 'str',
            'forecast_data_per_interval': 'list[WfmIntradayDataUpdateTopicIntradayForecastData]',
            'schedule_data_per_interval': 'list[WfmIntradayDataUpdateTopicIntradayScheduleData]',
            'historical_agent_data_per_interval': 'list[WfmIntradayDataUpdateTopicIntradayHistoricalAgentData]',
            'historical_queue_data_per_interval': 'list[WfmIntradayDataUpdateTopicIntradayHistoricalQueueData]',
            'performance_prediction_agent_data_per_interval': 'list[WfmIntradayDataUpdateTopicIntradayPerformancePredictionAgentData]',
            'performance_prediction_queue_data_per_interval': 'list[WfmIntradayDataUpdateTopicIntradayPerformancePredictionQueueData]'
        }

        self.attribute_map = {
            'media_type': 'mediaType',
            'forecast_data_per_interval': 'forecastDataPerInterval',
            'schedule_data_per_interval': 'scheduleDataPerInterval',
            'historical_agent_data_per_interval': 'historicalAgentDataPerInterval',
            'historical_queue_data_per_interval': 'historicalQueueDataPerInterval',
            'performance_prediction_agent_data_per_interval': 'performancePredictionAgentDataPerInterval',
            'performance_prediction_queue_data_per_interval': 'performancePredictionQueueDataPerInterval'
        }

        self._media_type = None
        self._forecast_data_per_interval = None
        self._schedule_data_per_interval = None
        self._historical_agent_data_per_interval = None
        self._historical_queue_data_per_interval = None
        self._performance_prediction_agent_data_per_interval = None
        self._performance_prediction_queue_data_per_interval = None

    @property
    def media_type(self):
        """
        Gets the media_type of this WfmIntradayDataUpdateTopicIntradayDataGroup.


        :return: The media_type of this WfmIntradayDataUpdateTopicIntradayDataGroup.
        :rtype: str
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """
        Sets the media_type of this WfmIntradayDataUpdateTopicIntradayDataGroup.


        :param media_type: The media_type of this WfmIntradayDataUpdateTopicIntradayDataGroup.
        :type: str
        """
        allowed_values = ["Voice", "Chat", "Email", "Callback", "Message"]
        if media_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for media_type -> " + media_type)
            self._media_type = "outdated_sdk_version"
        else:
            self._media_type = media_type

    @property
    def forecast_data_per_interval(self):
        """
        Gets the forecast_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.


        :return: The forecast_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.
        :rtype: list[WfmIntradayDataUpdateTopicIntradayForecastData]
        """
        return self._forecast_data_per_interval

    @forecast_data_per_interval.setter
    def forecast_data_per_interval(self, forecast_data_per_interval):
        """
        Sets the forecast_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.


        :param forecast_data_per_interval: The forecast_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.
        :type: list[WfmIntradayDataUpdateTopicIntradayForecastData]
        """
        
        self._forecast_data_per_interval = forecast_data_per_interval

    @property
    def schedule_data_per_interval(self):
        """
        Gets the schedule_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.


        :return: The schedule_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.
        :rtype: list[WfmIntradayDataUpdateTopicIntradayScheduleData]
        """
        return self._schedule_data_per_interval

    @schedule_data_per_interval.setter
    def schedule_data_per_interval(self, schedule_data_per_interval):
        """
        Sets the schedule_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.


        :param schedule_data_per_interval: The schedule_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.
        :type: list[WfmIntradayDataUpdateTopicIntradayScheduleData]
        """
        
        self._schedule_data_per_interval = schedule_data_per_interval

    @property
    def historical_agent_data_per_interval(self):
        """
        Gets the historical_agent_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.


        :return: The historical_agent_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.
        :rtype: list[WfmIntradayDataUpdateTopicIntradayHistoricalAgentData]
        """
        return self._historical_agent_data_per_interval

    @historical_agent_data_per_interval.setter
    def historical_agent_data_per_interval(self, historical_agent_data_per_interval):
        """
        Sets the historical_agent_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.


        :param historical_agent_data_per_interval: The historical_agent_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.
        :type: list[WfmIntradayDataUpdateTopicIntradayHistoricalAgentData]
        """
        
        self._historical_agent_data_per_interval = historical_agent_data_per_interval

    @property
    def historical_queue_data_per_interval(self):
        """
        Gets the historical_queue_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.


        :return: The historical_queue_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.
        :rtype: list[WfmIntradayDataUpdateTopicIntradayHistoricalQueueData]
        """
        return self._historical_queue_data_per_interval

    @historical_queue_data_per_interval.setter
    def historical_queue_data_per_interval(self, historical_queue_data_per_interval):
        """
        Sets the historical_queue_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.


        :param historical_queue_data_per_interval: The historical_queue_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.
        :type: list[WfmIntradayDataUpdateTopicIntradayHistoricalQueueData]
        """
        
        self._historical_queue_data_per_interval = historical_queue_data_per_interval

    @property
    def performance_prediction_agent_data_per_interval(self):
        """
        Gets the performance_prediction_agent_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.


        :return: The performance_prediction_agent_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.
        :rtype: list[WfmIntradayDataUpdateTopicIntradayPerformancePredictionAgentData]
        """
        return self._performance_prediction_agent_data_per_interval

    @performance_prediction_agent_data_per_interval.setter
    def performance_prediction_agent_data_per_interval(self, performance_prediction_agent_data_per_interval):
        """
        Sets the performance_prediction_agent_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.


        :param performance_prediction_agent_data_per_interval: The performance_prediction_agent_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.
        :type: list[WfmIntradayDataUpdateTopicIntradayPerformancePredictionAgentData]
        """
        
        self._performance_prediction_agent_data_per_interval = performance_prediction_agent_data_per_interval

    @property
    def performance_prediction_queue_data_per_interval(self):
        """
        Gets the performance_prediction_queue_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.


        :return: The performance_prediction_queue_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.
        :rtype: list[WfmIntradayDataUpdateTopicIntradayPerformancePredictionQueueData]
        """
        return self._performance_prediction_queue_data_per_interval

    @performance_prediction_queue_data_per_interval.setter
    def performance_prediction_queue_data_per_interval(self, performance_prediction_queue_data_per_interval):
        """
        Sets the performance_prediction_queue_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.


        :param performance_prediction_queue_data_per_interval: The performance_prediction_queue_data_per_interval of this WfmIntradayDataUpdateTopicIntradayDataGroup.
        :type: list[WfmIntradayDataUpdateTopicIntradayPerformancePredictionQueueData]
        """
        
        self._performance_prediction_queue_data_per_interval = performance_prediction_queue_data_per_interval

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class BuIntradayDataGroup(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        BuIntradayDataGroup - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'media_type': 'str',
            'forecast_data_summary': 'BuIntradayForecastData',
            'forecast_data_per_interval': 'list[BuIntradayForecastData]',
            'schedule_data_summary': 'BuIntradayScheduleData',
            'schedule_data_per_interval': 'list[BuIntradayScheduleData]',
            'performance_prediction_data_summary': 'IntradayPerformancePredictionData',
            'performance_prediction_data_per_interval': 'list[IntradayPerformancePredictionData]'
        }

        self.attribute_map = {
            'media_type': 'mediaType',
            'forecast_data_summary': 'forecastDataSummary',
            'forecast_data_per_interval': 'forecastDataPerInterval',
            'schedule_data_summary': 'scheduleDataSummary',
            'schedule_data_per_interval': 'scheduleDataPerInterval',
            'performance_prediction_data_summary': 'performancePredictionDataSummary',
            'performance_prediction_data_per_interval': 'performancePredictionDataPerInterval'
        }

        self._media_type = None
        self._forecast_data_summary = None
        self._forecast_data_per_interval = None
        self._schedule_data_summary = None
        self._schedule_data_per_interval = None
        self._performance_prediction_data_summary = None
        self._performance_prediction_data_per_interval = None

    @property
    def media_type(self):
        """
        Gets the media_type of this BuIntradayDataGroup.
        The media type associated with this intraday group

        :return: The media_type of this BuIntradayDataGroup.
        :rtype: str
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """
        Sets the media_type of this BuIntradayDataGroup.
        The media type associated with this intraday group

        :param media_type: The media_type of this BuIntradayDataGroup.
        :type: str
        """
        allowed_values = ["Voice", "Chat", "Email", "Callback", "Message"]
        if media_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for media_type -> " + media_type)
            self._media_type = "outdated_sdk_version"
        else:
            self._media_type = media_type

    @property
    def forecast_data_summary(self):
        """
        Gets the forecast_data_summary of this BuIntradayDataGroup.
        Forecast data summary for this date range

        :return: The forecast_data_summary of this BuIntradayDataGroup.
        :rtype: BuIntradayForecastData
        """
        return self._forecast_data_summary

    @forecast_data_summary.setter
    def forecast_data_summary(self, forecast_data_summary):
        """
        Sets the forecast_data_summary of this BuIntradayDataGroup.
        Forecast data summary for this date range

        :param forecast_data_summary: The forecast_data_summary of this BuIntradayDataGroup.
        :type: BuIntradayForecastData
        """
        
        self._forecast_data_summary = forecast_data_summary

    @property
    def forecast_data_per_interval(self):
        """
        Gets the forecast_data_per_interval of this BuIntradayDataGroup.
        Forecast data per interval for this date range

        :return: The forecast_data_per_interval of this BuIntradayDataGroup.
        :rtype: list[BuIntradayForecastData]
        """
        return self._forecast_data_per_interval

    @forecast_data_per_interval.setter
    def forecast_data_per_interval(self, forecast_data_per_interval):
        """
        Sets the forecast_data_per_interval of this BuIntradayDataGroup.
        Forecast data per interval for this date range

        :param forecast_data_per_interval: The forecast_data_per_interval of this BuIntradayDataGroup.
        :type: list[BuIntradayForecastData]
        """
        
        self._forecast_data_per_interval = forecast_data_per_interval

    @property
    def schedule_data_summary(self):
        """
        Gets the schedule_data_summary of this BuIntradayDataGroup.
        Schedule data summary for this date range

        :return: The schedule_data_summary of this BuIntradayDataGroup.
        :rtype: BuIntradayScheduleData
        """
        return self._schedule_data_summary

    @schedule_data_summary.setter
    def schedule_data_summary(self, schedule_data_summary):
        """
        Sets the schedule_data_summary of this BuIntradayDataGroup.
        Schedule data summary for this date range

        :param schedule_data_summary: The schedule_data_summary of this BuIntradayDataGroup.
        :type: BuIntradayScheduleData
        """
        
        self._schedule_data_summary = schedule_data_summary

    @property
    def schedule_data_per_interval(self):
        """
        Gets the schedule_data_per_interval of this BuIntradayDataGroup.
        Schedule data per interval for this date range

        :return: The schedule_data_per_interval of this BuIntradayDataGroup.
        :rtype: list[BuIntradayScheduleData]
        """
        return self._schedule_data_per_interval

    @schedule_data_per_interval.setter
    def schedule_data_per_interval(self, schedule_data_per_interval):
        """
        Sets the schedule_data_per_interval of this BuIntradayDataGroup.
        Schedule data per interval for this date range

        :param schedule_data_per_interval: The schedule_data_per_interval of this BuIntradayDataGroup.
        :type: list[BuIntradayScheduleData]
        """
        
        self._schedule_data_per_interval = schedule_data_per_interval

    @property
    def performance_prediction_data_summary(self):
        """
        Gets the performance_prediction_data_summary of this BuIntradayDataGroup.
        Performance prediction data summary for this date range

        :return: The performance_prediction_data_summary of this BuIntradayDataGroup.
        :rtype: IntradayPerformancePredictionData
        """
        return self._performance_prediction_data_summary

    @performance_prediction_data_summary.setter
    def performance_prediction_data_summary(self, performance_prediction_data_summary):
        """
        Sets the performance_prediction_data_summary of this BuIntradayDataGroup.
        Performance prediction data summary for this date range

        :param performance_prediction_data_summary: The performance_prediction_data_summary of this BuIntradayDataGroup.
        :type: IntradayPerformancePredictionData
        """
        
        self._performance_prediction_data_summary = performance_prediction_data_summary

    @property
    def performance_prediction_data_per_interval(self):
        """
        Gets the performance_prediction_data_per_interval of this BuIntradayDataGroup.
        Performance prediction data per interval for this date range

        :return: The performance_prediction_data_per_interval of this BuIntradayDataGroup.
        :rtype: list[IntradayPerformancePredictionData]
        """
        return self._performance_prediction_data_per_interval

    @performance_prediction_data_per_interval.setter
    def performance_prediction_data_per_interval(self, performance_prediction_data_per_interval):
        """
        Sets the performance_prediction_data_per_interval of this BuIntradayDataGroup.
        Performance prediction data per interval for this date range

        :param performance_prediction_data_per_interval: The performance_prediction_data_per_interval of this BuIntradayDataGroup.
        :type: list[IntradayPerformancePredictionData]
        """
        
        self._performance_prediction_data_per_interval = performance_prediction_data_per_interval

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ResponseConfig(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ResponseConfig - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'translation_map': 'dict(str, str)',
            'translation_map_defaults': 'dict(str, str)',
            'success_template': 'str',
            'success_template_uri': 'str'
        }

        self.attribute_map = {
            'translation_map': 'translationMap',
            'translation_map_defaults': 'translationMapDefaults',
            'success_template': 'successTemplate',
            'success_template_uri': 'successTemplateUri'
        }

        self._translation_map = None
        self._translation_map_defaults = None
        self._success_template = None
        self._success_template_uri = None

    @property
    def translation_map(self):
        """
        Gets the translation_map of this ResponseConfig.
        Map 'attribute name' and 'JSON path' pairs used to extract data from REST response.

        :return: The translation_map of this ResponseConfig.
        :rtype: dict(str, str)
        """
        return self._translation_map

    @translation_map.setter
    def translation_map(self, translation_map):
        """
        Sets the translation_map of this ResponseConfig.
        Map 'attribute name' and 'JSON path' pairs used to extract data from REST response.

        :param translation_map: The translation_map of this ResponseConfig.
        :type: dict(str, str)
        """
        
        self._translation_map = translation_map

    @property
    def translation_map_defaults(self):
        """
        Gets the translation_map_defaults of this ResponseConfig.
        Map 'attribute name' and 'default value' pairs used as fallback values if JSON path extraction fails for specified key.

        :return: The translation_map_defaults of this ResponseConfig.
        :rtype: dict(str, str)
        """
        return self._translation_map_defaults

    @translation_map_defaults.setter
    def translation_map_defaults(self, translation_map_defaults):
        """
        Sets the translation_map_defaults of this ResponseConfig.
        Map 'attribute name' and 'default value' pairs used as fallback values if JSON path extraction fails for specified key.

        :param translation_map_defaults: The translation_map_defaults of this ResponseConfig.
        :type: dict(str, str)
        """
        
        self._translation_map_defaults = translation_map_defaults

    @property
    def success_template(self):
        """
        Gets the success_template of this ResponseConfig.
        Velocity template to build response to return from Action.

        :return: The success_template of this ResponseConfig.
        :rtype: str
        """
        return self._success_template

    @success_template.setter
    def success_template(self, success_template):
        """
        Sets the success_template of this ResponseConfig.
        Velocity template to build response to return from Action.

        :param success_template: The success_template of this ResponseConfig.
        :type: str
        """
        
        self._success_template = success_template

    @property
    def success_template_uri(self):
        """
        Gets the success_template_uri of this ResponseConfig.
        URI to retrieve success template.

        :return: The success_template_uri of this ResponseConfig.
        :rtype: str
        """
        return self._success_template_uri

    @success_template_uri.setter
    def success_template_uri(self, success_template_uri):
        """
        Sets the success_template_uri of this ResponseConfig.
        URI to retrieve success template.

        :param success_template_uri: The success_template_uri of this ResponseConfig.
        :type: str
        """
        
        self._success_template_uri = success_template_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CampaignInteractions(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CampaignInteractions - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'campaign': 'DomainEntityRef',
            'pending_interactions': 'list[CampaignInteraction]',
            'proceeding_interactions': 'list[CampaignInteraction]',
            'previewing_interactions': 'list[CampaignInteraction]',
            'interacting_interactions': 'list[CampaignInteraction]',
            'scheduled_interactions': 'list[CampaignInteraction]'
        }

        self.attribute_map = {
            'campaign': 'campaign',
            'pending_interactions': 'pendingInteractions',
            'proceeding_interactions': 'proceedingInteractions',
            'previewing_interactions': 'previewingInteractions',
            'interacting_interactions': 'interactingInteractions',
            'scheduled_interactions': 'scheduledInteractions'
        }

        self._campaign = None
        self._pending_interactions = None
        self._proceeding_interactions = None
        self._previewing_interactions = None
        self._interacting_interactions = None
        self._scheduled_interactions = None

    @property
    def campaign(self):
        """
        Gets the campaign of this CampaignInteractions.


        :return: The campaign of this CampaignInteractions.
        :rtype: DomainEntityRef
        """
        return self._campaign

    @campaign.setter
    def campaign(self, campaign):
        """
        Sets the campaign of this CampaignInteractions.


        :param campaign: The campaign of this CampaignInteractions.
        :type: DomainEntityRef
        """
        
        self._campaign = campaign

    @property
    def pending_interactions(self):
        """
        Gets the pending_interactions of this CampaignInteractions.


        :return: The pending_interactions of this CampaignInteractions.
        :rtype: list[CampaignInteraction]
        """
        return self._pending_interactions

    @pending_interactions.setter
    def pending_interactions(self, pending_interactions):
        """
        Sets the pending_interactions of this CampaignInteractions.


        :param pending_interactions: The pending_interactions of this CampaignInteractions.
        :type: list[CampaignInteraction]
        """
        
        self._pending_interactions = pending_interactions

    @property
    def proceeding_interactions(self):
        """
        Gets the proceeding_interactions of this CampaignInteractions.


        :return: The proceeding_interactions of this CampaignInteractions.
        :rtype: list[CampaignInteraction]
        """
        return self._proceeding_interactions

    @proceeding_interactions.setter
    def proceeding_interactions(self, proceeding_interactions):
        """
        Sets the proceeding_interactions of this CampaignInteractions.


        :param proceeding_interactions: The proceeding_interactions of this CampaignInteractions.
        :type: list[CampaignInteraction]
        """
        
        self._proceeding_interactions = proceeding_interactions

    @property
    def previewing_interactions(self):
        """
        Gets the previewing_interactions of this CampaignInteractions.


        :return: The previewing_interactions of this CampaignInteractions.
        :rtype: list[CampaignInteraction]
        """
        return self._previewing_interactions

    @previewing_interactions.setter
    def previewing_interactions(self, previewing_interactions):
        """
        Sets the previewing_interactions of this CampaignInteractions.


        :param previewing_interactions: The previewing_interactions of this CampaignInteractions.
        :type: list[CampaignInteraction]
        """
        
        self._previewing_interactions = previewing_interactions

    @property
    def interacting_interactions(self):
        """
        Gets the interacting_interactions of this CampaignInteractions.


        :return: The interacting_interactions of this CampaignInteractions.
        :rtype: list[CampaignInteraction]
        """
        return self._interacting_interactions

    @interacting_interactions.setter
    def interacting_interactions(self, interacting_interactions):
        """
        Sets the interacting_interactions of this CampaignInteractions.


        :param interacting_interactions: The interacting_interactions of this CampaignInteractions.
        :type: list[CampaignInteraction]
        """
        
        self._interacting_interactions = interacting_interactions

    @property
    def scheduled_interactions(self):
        """
        Gets the scheduled_interactions of this CampaignInteractions.


        :return: The scheduled_interactions of this CampaignInteractions.
        :rtype: list[CampaignInteraction]
        """
        return self._scheduled_interactions

    @scheduled_interactions.setter
    def scheduled_interactions(self, scheduled_interactions):
        """
        Sets the scheduled_interactions of this CampaignInteractions.


        :param scheduled_interactions: The scheduled_interactions of this CampaignInteractions.
        :type: list[CampaignInteraction]
        """
        
        self._scheduled_interactions = scheduled_interactions

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class LocationDefinition(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        LocationDefinition - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'contact_user': 'AddressableEntityRef',
            'emergency_number': 'LocationEmergencyNumber',
            'address': 'LocationAddress',
            'state': 'str',
            'notes': 'str',
            'version': 'int',
            'path': 'list[str]',
            'profile_image': 'list[LocationImage]',
            'floorplan_image': 'list[LocationImage]',
            'address_verification_details': 'LocationAddressVerificationDetails',
            'address_verified': 'bool',
            'address_stored': 'bool',
            'images': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'contact_user': 'contactUser',
            'emergency_number': 'emergencyNumber',
            'address': 'address',
            'state': 'state',
            'notes': 'notes',
            'version': 'version',
            'path': 'path',
            'profile_image': 'profileImage',
            'floorplan_image': 'floorplanImage',
            'address_verification_details': 'addressVerificationDetails',
            'address_verified': 'addressVerified',
            'address_stored': 'addressStored',
            'images': 'images',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._contact_user = None
        self._emergency_number = None
        self._address = None
        self._state = None
        self._notes = None
        self._version = None
        self._path = None
        self._profile_image = None
        self._floorplan_image = None
        self._address_verification_details = None
        self._address_verified = None
        self._address_stored = None
        self._images = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this LocationDefinition.
        The globally unique identifier for the object.

        :return: The id of this LocationDefinition.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LocationDefinition.
        The globally unique identifier for the object.

        :param id: The id of this LocationDefinition.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this LocationDefinition.


        :return: The name of this LocationDefinition.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LocationDefinition.


        :param name: The name of this LocationDefinition.
        :type: str
        """
        
        self._name = name

    @property
    def contact_user(self):
        """
        Gets the contact_user of this LocationDefinition.
        Site contact for the location entity

        :return: The contact_user of this LocationDefinition.
        :rtype: AddressableEntityRef
        """
        return self._contact_user

    @contact_user.setter
    def contact_user(self, contact_user):
        """
        Sets the contact_user of this LocationDefinition.
        Site contact for the location entity

        :param contact_user: The contact_user of this LocationDefinition.
        :type: AddressableEntityRef
        """
        
        self._contact_user = contact_user

    @property
    def emergency_number(self):
        """
        Gets the emergency_number of this LocationDefinition.
        Emergency number for the location entity

        :return: The emergency_number of this LocationDefinition.
        :rtype: LocationEmergencyNumber
        """
        return self._emergency_number

    @emergency_number.setter
    def emergency_number(self, emergency_number):
        """
        Sets the emergency_number of this LocationDefinition.
        Emergency number for the location entity

        :param emergency_number: The emergency_number of this LocationDefinition.
        :type: LocationEmergencyNumber
        """
        
        self._emergency_number = emergency_number

    @property
    def address(self):
        """
        Gets the address of this LocationDefinition.


        :return: The address of this LocationDefinition.
        :rtype: LocationAddress
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this LocationDefinition.


        :param address: The address of this LocationDefinition.
        :type: LocationAddress
        """
        
        self._address = address

    @property
    def state(self):
        """
        Gets the state of this LocationDefinition.
        Current state of the location entity

        :return: The state of this LocationDefinition.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this LocationDefinition.
        Current state of the location entity

        :param state: The state of this LocationDefinition.
        :type: str
        """
        allowed_values = ["active", "deleted"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def notes(self):
        """
        Gets the notes of this LocationDefinition.
        Notes for the location entity

        :return: The notes of this LocationDefinition.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """
        Sets the notes of this LocationDefinition.
        Notes for the location entity

        :param notes: The notes of this LocationDefinition.
        :type: str
        """
        
        self._notes = notes

    @property
    def version(self):
        """
        Gets the version of this LocationDefinition.
        Current version of the location entity, value to be supplied should be retrieved by a GET or on create/update response

        :return: The version of this LocationDefinition.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this LocationDefinition.
        Current version of the location entity, value to be supplied should be retrieved by a GET or on create/update response

        :param version: The version of this LocationDefinition.
        :type: int
        """
        
        self._version = version

    @property
    def path(self):
        """
        Gets the path of this LocationDefinition.
        A list of ancestor IDs in order

        :return: The path of this LocationDefinition.
        :rtype: list[str]
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this LocationDefinition.
        A list of ancestor IDs in order

        :param path: The path of this LocationDefinition.
        :type: list[str]
        """
        
        self._path = path

    @property
    def profile_image(self):
        """
        Gets the profile_image of this LocationDefinition.
        Profile image of the location entity, retrieved with ?expand=images query parameter

        :return: The profile_image of this LocationDefinition.
        :rtype: list[LocationImage]
        """
        return self._profile_image

    @profile_image.setter
    def profile_image(self, profile_image):
        """
        Sets the profile_image of this LocationDefinition.
        Profile image of the location entity, retrieved with ?expand=images query parameter

        :param profile_image: The profile_image of this LocationDefinition.
        :type: list[LocationImage]
        """
        
        self._profile_image = profile_image

    @property
    def floorplan_image(self):
        """
        Gets the floorplan_image of this LocationDefinition.
        Floorplan images of the location entity, retrieved with ?expand=images query parameter

        :return: The floorplan_image of this LocationDefinition.
        :rtype: list[LocationImage]
        """
        return self._floorplan_image

    @floorplan_image.setter
    def floorplan_image(self, floorplan_image):
        """
        Sets the floorplan_image of this LocationDefinition.
        Floorplan images of the location entity, retrieved with ?expand=images query parameter

        :param floorplan_image: The floorplan_image of this LocationDefinition.
        :type: list[LocationImage]
        """
        
        self._floorplan_image = floorplan_image

    @property
    def address_verification_details(self):
        """
        Gets the address_verification_details of this LocationDefinition.
        Address verification information, retrieve dwith the ?expand=addressVerificationDetails query parameter

        :return: The address_verification_details of this LocationDefinition.
        :rtype: LocationAddressVerificationDetails
        """
        return self._address_verification_details

    @address_verification_details.setter
    def address_verification_details(self, address_verification_details):
        """
        Sets the address_verification_details of this LocationDefinition.
        Address verification information, retrieve dwith the ?expand=addressVerificationDetails query parameter

        :param address_verification_details: The address_verification_details of this LocationDefinition.
        :type: LocationAddressVerificationDetails
        """
        
        self._address_verification_details = address_verification_details

    @property
    def address_verified(self):
        """
        Gets the address_verified of this LocationDefinition.
        Boolean field which states if the address has been verified as an actual address

        :return: The address_verified of this LocationDefinition.
        :rtype: bool
        """
        return self._address_verified

    @address_verified.setter
    def address_verified(self, address_verified):
        """
        Sets the address_verified of this LocationDefinition.
        Boolean field which states if the address has been verified as an actual address

        :param address_verified: The address_verified of this LocationDefinition.
        :type: bool
        """
        
        self._address_verified = address_verified

    @property
    def address_stored(self):
        """
        Gets the address_stored of this LocationDefinition.
        Boolean field which states if the address has been stored for E911

        :return: The address_stored of this LocationDefinition.
        :rtype: bool
        """
        return self._address_stored

    @address_stored.setter
    def address_stored(self, address_stored):
        """
        Sets the address_stored of this LocationDefinition.
        Boolean field which states if the address has been stored for E911

        :param address_stored: The address_stored of this LocationDefinition.
        :type: bool
        """
        
        self._address_stored = address_stored

    @property
    def images(self):
        """
        Gets the images of this LocationDefinition.


        :return: The images of this LocationDefinition.
        :rtype: str
        """
        return self._images

    @images.setter
    def images(self, images):
        """
        Sets the images of this LocationDefinition.


        :param images: The images of this LocationDefinition.
        :type: str
        """
        
        self._images = images

    @property
    def self_uri(self):
        """
        Gets the self_uri of this LocationDefinition.
        The URI for this object

        :return: The self_uri of this LocationDefinition.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this LocationDefinition.
        The URI for this object

        :param self_uri: The self_uri of this LocationDefinition.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class PatchContentOffer(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PatchContentOffer - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'image_url': 'str',
            'display_mode': 'str',
            'layout_mode': 'str',
            'title': 'str',
            'headline': 'str',
            'body': 'str',
            'call_to_action': 'PatchCallToAction',
            'style': 'PatchContentOfferStylingConfiguration'
        }

        self.attribute_map = {
            'image_url': 'imageUrl',
            'display_mode': 'displayMode',
            'layout_mode': 'layoutMode',
            'title': 'title',
            'headline': 'headline',
            'body': 'body',
            'call_to_action': 'callToAction',
            'style': 'style'
        }

        self._image_url = None
        self._display_mode = None
        self._layout_mode = None
        self._title = None
        self._headline = None
        self._body = None
        self._call_to_action = None
        self._style = None

    @property
    def image_url(self):
        """
        Gets the image_url of this PatchContentOffer.
        URL for image displayed to the customer when displaying content offer.

        :return: The image_url of this PatchContentOffer.
        :rtype: str
        """
        return self._image_url

    @image_url.setter
    def image_url(self, image_url):
        """
        Sets the image_url of this PatchContentOffer.
        URL for image displayed to the customer when displaying content offer.

        :param image_url: The image_url of this PatchContentOffer.
        :type: str
        """
        
        self._image_url = image_url

    @property
    def display_mode(self):
        """
        Gets the display_mode of this PatchContentOffer.
        The display mode of Genesys Widgets when displaying content offer.

        :return: The display_mode of this PatchContentOffer.
        :rtype: str
        """
        return self._display_mode

    @display_mode.setter
    def display_mode(self, display_mode):
        """
        Sets the display_mode of this PatchContentOffer.
        The display mode of Genesys Widgets when displaying content offer.

        :param display_mode: The display_mode of this PatchContentOffer.
        :type: str
        """
        allowed_values = ["Modal", "Overlay", "Toast"]
        if display_mode.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for display_mode -> " + display_mode)
            self._display_mode = "outdated_sdk_version"
        else:
            self._display_mode = display_mode

    @property
    def layout_mode(self):
        """
        Gets the layout_mode of this PatchContentOffer.
        The layout mode of the text shown to the user when displaying content offer.

        :return: The layout_mode of this PatchContentOffer.
        :rtype: str
        """
        return self._layout_mode

    @layout_mode.setter
    def layout_mode(self, layout_mode):
        """
        Sets the layout_mode of this PatchContentOffer.
        The layout mode of the text shown to the user when displaying content offer.

        :param layout_mode: The layout_mode of this PatchContentOffer.
        :type: str
        """
        allowed_values = ["TextOnly", "ImageOnly", "LeftText", "RightText", "TopText", "BottomText"]
        if layout_mode.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for layout_mode -> " + layout_mode)
            self._layout_mode = "outdated_sdk_version"
        else:
            self._layout_mode = layout_mode

    @property
    def title(self):
        """
        Gets the title of this PatchContentOffer.
        Title used in the header of the content offer.

        :return: The title of this PatchContentOffer.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this PatchContentOffer.
        Title used in the header of the content offer.

        :param title: The title of this PatchContentOffer.
        :type: str
        """
        
        self._title = title

    @property
    def headline(self):
        """
        Gets the headline of this PatchContentOffer.
        Headline displayed above the body text of the content offer.

        :return: The headline of this PatchContentOffer.
        :rtype: str
        """
        return self._headline

    @headline.setter
    def headline(self, headline):
        """
        Sets the headline of this PatchContentOffer.
        Headline displayed above the body text of the content offer.

        :param headline: The headline of this PatchContentOffer.
        :type: str
        """
        
        self._headline = headline

    @property
    def body(self):
        """
        Gets the body of this PatchContentOffer.
        Body text of the content offer.

        :return: The body of this PatchContentOffer.
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """
        Sets the body of this PatchContentOffer.
        Body text of the content offer.

        :param body: The body of this PatchContentOffer.
        :type: str
        """
        
        self._body = body

    @property
    def call_to_action(self):
        """
        Gets the call_to_action of this PatchContentOffer.
        Properties customizing the call to action button on the content offer.

        :return: The call_to_action of this PatchContentOffer.
        :rtype: PatchCallToAction
        """
        return self._call_to_action

    @call_to_action.setter
    def call_to_action(self, call_to_action):
        """
        Sets the call_to_action of this PatchContentOffer.
        Properties customizing the call to action button on the content offer.

        :param call_to_action: The call_to_action of this PatchContentOffer.
        :type: PatchCallToAction
        """
        
        self._call_to_action = call_to_action

    @property
    def style(self):
        """
        Gets the style of this PatchContentOffer.
        Properties customizing the styling of the content offer.

        :return: The style of this PatchContentOffer.
        :rtype: PatchContentOfferStylingConfiguration
        """
        return self._style

    @style.setter
    def style(self, style):
        """
        Sets the style of this PatchContentOffer.
        Properties customizing the styling of the content offer.

        :param style: The style of this PatchContentOffer.
        :type: PatchContentOfferStylingConfiguration
        """
        
        self._style = style

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ContactColumnTimeZone(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ContactColumnTimeZone - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'time_zone': 'str',
            'column_type': 'str'
        }

        self.attribute_map = {
            'time_zone': 'timeZone',
            'column_type': 'columnType'
        }

        self._time_zone = None
        self._column_type = None

    @property
    def time_zone(self):
        """
        Gets the time_zone of this ContactColumnTimeZone.
        Time zone that the column matched to. Time zones are represented as a string of the zone name as found in the IANA time zone database. For example: UTC, Etc/UTC, or Europe/London

        :return: The time_zone of this ContactColumnTimeZone.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this ContactColumnTimeZone.
        Time zone that the column matched to. Time zones are represented as a string of the zone name as found in the IANA time zone database. For example: UTC, Etc/UTC, or Europe/London

        :param time_zone: The time_zone of this ContactColumnTimeZone.
        :type: str
        """
        
        self._time_zone = time_zone

    @property
    def column_type(self):
        """
        Gets the column_type of this ContactColumnTimeZone.
        Column Type will be either PHONE or ZIP

        :return: The column_type of this ContactColumnTimeZone.
        :rtype: str
        """
        return self._column_type

    @column_type.setter
    def column_type(self, column_type):
        """
        Sets the column_type of this ContactColumnTimeZone.
        Column Type will be either PHONE or ZIP

        :param column_type: The column_type of this ContactColumnTimeZone.
        :type: str
        """
        allowed_values = ["PHONE", "ZIP"]
        if column_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for column_type -> " + column_type)
            self._column_type = "outdated_sdk_version"
        else:
            self._column_type = column_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class TopicRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TopicRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'description': 'str',
            'strictness': 'str',
            'program_ids': 'list[str]',
            'tags': 'list[str]',
            'dialect': 'str',
            'participants': 'str',
            'phrases': 'list[Phrase]'
        }

        self.attribute_map = {
            'name': 'name',
            'description': 'description',
            'strictness': 'strictness',
            'program_ids': 'programIds',
            'tags': 'tags',
            'dialect': 'dialect',
            'participants': 'participants',
            'phrases': 'phrases'
        }

        self._name = None
        self._description = None
        self._strictness = None
        self._program_ids = None
        self._tags = None
        self._dialect = None
        self._participants = None
        self._phrases = None

    @property
    def name(self):
        """
        Gets the name of this TopicRequest.
        The topic name

        :return: The name of this TopicRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TopicRequest.
        The topic name

        :param name: The name of this TopicRequest.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this TopicRequest.
        The topic description

        :return: The description of this TopicRequest.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this TopicRequest.
        The topic description

        :param description: The description of this TopicRequest.
        :type: str
        """
        
        self._description = description

    @property
    def strictness(self):
        """
        Gets the strictness of this TopicRequest.
        The topic strictness, default value is 72

        :return: The strictness of this TopicRequest.
        :rtype: str
        """
        return self._strictness

    @strictness.setter
    def strictness(self, strictness):
        """
        Sets the strictness of this TopicRequest.
        The topic strictness, default value is 72

        :param strictness: The strictness of this TopicRequest.
        :type: str
        """
        allowed_values = ["1", "55", "65", "72", "85", "90"]
        if strictness.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for strictness -> " + strictness)
            self._strictness = "outdated_sdk_version"
        else:
            self._strictness = strictness

    @property
    def program_ids(self):
        """
        Gets the program_ids of this TopicRequest.
        The ids of programs associated to the topic

        :return: The program_ids of this TopicRequest.
        :rtype: list[str]
        """
        return self._program_ids

    @program_ids.setter
    def program_ids(self, program_ids):
        """
        Sets the program_ids of this TopicRequest.
        The ids of programs associated to the topic

        :param program_ids: The program_ids of this TopicRequest.
        :type: list[str]
        """
        
        self._program_ids = program_ids

    @property
    def tags(self):
        """
        Gets the tags of this TopicRequest.
        The topic tags

        :return: The tags of this TopicRequest.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this TopicRequest.
        The topic tags

        :param tags: The tags of this TopicRequest.
        :type: list[str]
        """
        
        self._tags = tags

    @property
    def dialect(self):
        """
        Gets the dialect of this TopicRequest.
        The topic dialect

        :return: The dialect of this TopicRequest.
        :rtype: str
        """
        return self._dialect

    @dialect.setter
    def dialect(self, dialect):
        """
        Sets the dialect of this TopicRequest.
        The topic dialect

        :param dialect: The dialect of this TopicRequest.
        :type: str
        """
        
        self._dialect = dialect

    @property
    def participants(self):
        """
        Gets the participants of this TopicRequest.
        The topic participants, default value is All

        :return: The participants of this TopicRequest.
        :rtype: str
        """
        return self._participants

    @participants.setter
    def participants(self, participants):
        """
        Sets the participants of this TopicRequest.
        The topic participants, default value is All

        :param participants: The participants of this TopicRequest.
        :type: str
        """
        allowed_values = ["External", "Internal", "All"]
        if participants.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for participants -> " + participants)
            self._participants = "outdated_sdk_version"
        else:
            self._participants = participants

    @property
    def phrases(self):
        """
        Gets the phrases of this TopicRequest.
        The topic phrases

        :return: The phrases of this TopicRequest.
        :rtype: list[Phrase]
        """
        return self._phrases

    @phrases.setter
    def phrases(self, phrases):
        """
        Sets the phrases of this TopicRequest.
        The topic phrases

        :param phrases: The phrases of this TopicRequest.
        :type: list[Phrase]
        """
        
        self._phrases = phrases

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SIPSearchPublicRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SIPSearchPublicRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'call_id': 'str',
            'to_user': 'str',
            'from_user': 'str',
            'conversation_id': 'str',
            'participant_id': 'str',
            'date_start': 'datetime',
            'date_end': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'call_id': 'callId',
            'to_user': 'toUser',
            'from_user': 'fromUser',
            'conversation_id': 'conversationId',
            'participant_id': 'participantId',
            'date_start': 'dateStart',
            'date_end': 'dateEnd',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._call_id = None
        self._to_user = None
        self._from_user = None
        self._conversation_id = None
        self._participant_id = None
        self._date_start = None
        self._date_end = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this SIPSearchPublicRequest.
        The globally unique identifier for the object.

        :return: The id of this SIPSearchPublicRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SIPSearchPublicRequest.
        The globally unique identifier for the object.

        :param id: The id of this SIPSearchPublicRequest.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this SIPSearchPublicRequest.


        :return: The name of this SIPSearchPublicRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SIPSearchPublicRequest.


        :param name: The name of this SIPSearchPublicRequest.
        :type: str
        """
        
        self._name = name

    @property
    def call_id(self):
        """
        Gets the call_id of this SIPSearchPublicRequest.
        unique identification of the placed call

        :return: The call_id of this SIPSearchPublicRequest.
        :rtype: str
        """
        return self._call_id

    @call_id.setter
    def call_id(self, call_id):
        """
        Sets the call_id of this SIPSearchPublicRequest.
        unique identification of the placed call

        :param call_id: The call_id of this SIPSearchPublicRequest.
        :type: str
        """
        
        self._call_id = call_id

    @property
    def to_user(self):
        """
        Gets the to_user of this SIPSearchPublicRequest.
        SIP user to who the call was placed

        :return: The to_user of this SIPSearchPublicRequest.
        :rtype: str
        """
        return self._to_user

    @to_user.setter
    def to_user(self, to_user):
        """
        Sets the to_user of this SIPSearchPublicRequest.
        SIP user to who the call was placed

        :param to_user: The to_user of this SIPSearchPublicRequest.
        :type: str
        """
        
        self._to_user = to_user

    @property
    def from_user(self):
        """
        Gets the from_user of this SIPSearchPublicRequest.
        SIP user who placed the call

        :return: The from_user of this SIPSearchPublicRequest.
        :rtype: str
        """
        return self._from_user

    @from_user.setter
    def from_user(self, from_user):
        """
        Sets the from_user of this SIPSearchPublicRequest.
        SIP user who placed the call

        :param from_user: The from_user of this SIPSearchPublicRequest.
        :type: str
        """
        
        self._from_user = from_user

    @property
    def conversation_id(self):
        """
        Gets the conversation_id of this SIPSearchPublicRequest.
        Unique identification of the conversation

        :return: The conversation_id of this SIPSearchPublicRequest.
        :rtype: str
        """
        return self._conversation_id

    @conversation_id.setter
    def conversation_id(self, conversation_id):
        """
        Sets the conversation_id of this SIPSearchPublicRequest.
        Unique identification of the conversation

        :param conversation_id: The conversation_id of this SIPSearchPublicRequest.
        :type: str
        """
        
        self._conversation_id = conversation_id

    @property
    def participant_id(self):
        """
        Gets the participant_id of this SIPSearchPublicRequest.
        Unique identification of the participant

        :return: The participant_id of this SIPSearchPublicRequest.
        :rtype: str
        """
        return self._participant_id

    @participant_id.setter
    def participant_id(self, participant_id):
        """
        Sets the participant_id of this SIPSearchPublicRequest.
        Unique identification of the participant

        :param participant_id: The participant_id of this SIPSearchPublicRequest.
        :type: str
        """
        
        self._participant_id = participant_id

    @property
    def date_start(self):
        """
        Gets the date_start of this SIPSearchPublicRequest.
        Start date of the search. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_start of this SIPSearchPublicRequest.
        :rtype: datetime
        """
        return self._date_start

    @date_start.setter
    def date_start(self, date_start):
        """
        Sets the date_start of this SIPSearchPublicRequest.
        Start date of the search. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_start: The date_start of this SIPSearchPublicRequest.
        :type: datetime
        """
        
        self._date_start = date_start

    @property
    def date_end(self):
        """
        Gets the date_end of this SIPSearchPublicRequest.
        End date of the search. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_end of this SIPSearchPublicRequest.
        :rtype: datetime
        """
        return self._date_end

    @date_end.setter
    def date_end(self, date_end):
        """
        Sets the date_end of this SIPSearchPublicRequest.
        End date of the search. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_end: The date_end of this SIPSearchPublicRequest.
        :type: datetime
        """
        
        self._date_end = date_end

    @property
    def self_uri(self):
        """
        Gets the self_uri of this SIPSearchPublicRequest.
        The URI for this object

        :return: The self_uri of this SIPSearchPublicRequest.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this SIPSearchPublicRequest.
        The URI for this object

        :param self_uri: The self_uri of this SIPSearchPublicRequest.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

